Plugin types
============

Misc plugins
------------

TODO

VCS plugins
-----------

TODO

Renderer plugins
----------------

TODO

README plugins
^^^^^^^^^^^^^^

TODO

Target plugins
^^^^^^^^^^^^^^

TODO

TODO

Action plugins
--------------

TODO

Multiprocessing, GIL, etc.
